@@ -3,6 +3,7 @@
 import pytest
 
 from bec_lib.client import SystemConfig
+from bec_lib.tests.fixtures import bec_client_mock
 
 
 def test_system_config():
@@ -20,3 +21,12 @@ def test_system_config():
     with pytest.raises(ValueError):
         config = SystemConfig(file_suffix="@")
         config = SystemConfig(file_directory="ä")
+
+
+def test_show_all_commands(bec_client_mock, capsys):
+    """Test the show_all_commands method."""
+    client = bec_client_mock
+    client.show_all_commands()
+    captured = capsys.readouterr()
+    assert "User macros" in captured.out
+    assert "Scans" in captured.out
