@@ -49,7 +49,7 @@ def test_read(dev: Any):
             },
             metadata={"scan_id": "scan_id", "scan_type": "scan_type"},
         )
-        res = dev.samx.read()
+        res = dev.samx.read(cached=True)
         mock_get.assert_called_once_with(MessageEndpoints.device_readback("samx"))
         assert res == {
             "samx": {"value": 0, "timestamp": 1701105880.1711318},
@@ -68,7 +68,7 @@ def test_read_filtered_hints(dev: Any):
             },
             metadata={"scan_id": "scan_id", "scan_type": "scan_type"},
         )
-        res = dev.samx.read(filter_to_hints=True)
+        res = dev.samx.read(cached=True, filter_to_hints=True)
         mock_get.assert_called_once_with(MessageEndpoints.device_readback("samx"))
         assert res == {"samx": {"value": 0, "timestamp": 1701105880.1711318}}
 
@@ -83,7 +83,7 @@ def test_read_use_read(dev: Any):
         mock_get.return_value = messages.DeviceMessage(
             signals=data, metadata={"scan_id": "scan_id", "scan_type": "scan_type"}
         )
-        res = dev.samx.read(use_readback=False)
+        res = dev.samx.read(cached=True, use_readback=False)
         mock_get.assert_called_once_with(MessageEndpoints.device_read("samx"))
         assert res == data
 
@@ -100,7 +100,7 @@ def test_read_nested_device(dev: Any):
         mock_get.return_value = messages.DeviceMessage(
             signals=data, metadata={"scan_id": "scan_id", "scan_type": "scan_type"}
         )
-        res = dev.dyn_signals.messages.read()
+        res = dev.dyn_signals.messages.read(cached=True)
         mock_get.assert_called_once_with(MessageEndpoints.device_readback("dyn_signals"))
         assert res == data
 
